==> haskell-aeson-1.2.4.0-9-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-aeson.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: aeson
version: 1.2.4.0
id: aeson-1.2.4.0-29Ui7SKICkn4HdMa5tx6LD
key: aeson-1.2.4.0-29Ui7SKICkn4HdMa5tx6LD
license: BSD3
copyright: (c) 2011-2016 Bryan O'\''Sullivan
           (c) 2011 MailRank, Inc.
maintainer: Adam Bergmark <adam@bergmark.nl>
stability: experimental
homepage: https://github.com/bos/aeson
synopsis: Fast JSON parsing and encoding
description:
    A JSON parsing and encoding library optimized for ease of use
    and high performance.
    .
    To get started, see the documentation for the @Data.Aeson@ module
    below.
    .
    Parsing performance on a late 2013 MacBook Pro (2.6GHz Core i7),
    running 64-bit GHC 7.10.1, for mostly-English tweets from Twitter'\''s
    JSON search API:
    .
    * 6.4 KB payloads, English: 7570 msg\/sec (47.6 MB\/sec)
    .
    * 14.6 KB payloads, Japanese: 3261 msg\/sec (46.6 MB\/sec)
    .
    Encoding performance on the same machine and data:
    .
    * 6.4 KB payloads, English: 22738 msg\/sec (142.9 MB\/sec)
    .
    * 14.6 KB payloads, Japanese: 15911 msg\/sec (227.4 MB\/sec)
    .
    (A note on naming: in Greek mythology, Aeson was the father of Jason.)
category: Text, Web, JSON
author: Bryan O'\''Sullivan <bos@serpentine.com>
exposed: True
indefinite: False
exposed-modules:
    Data.Aeson Data.Aeson.Encode Data.Aeson.Encoding
    Data.Aeson.Encoding.Internal Data.Aeson.Internal
    Data.Aeson.Internal.Time Data.Aeson.Parser
    Data.Aeson.Parser.Internal Data.Aeson.TH Data.Aeson.Text
    Data.Aeson.Types
hidden-modules: Data.Aeson.Compat Data.Aeson.Encoding.Builder
                Data.Aeson.Internal.Functions Data.Aeson.Parser.Unescape
                Data.Aeson.Parser.Time Data.Aeson.Types.FromJSON
                Data.Aeson.Types.Generic Data.Aeson.Types.ToJSON
                Data.Aeson.Types.Class Data.Aeson.Types.Internal
                Data.Attoparsec.Time Data.Attoparsec.Time.Internal
                Data.Aeson.Parser.UnescapePure
abi: 2daf6700d9ef385ba2659a6e8aebe988
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/aeson-1.2.4.0
library-dirs: /usr/lib/ghc-8.2.2/site-local/aeson-1.2.4.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/aeson-1.2.4.0
hs-libraries: HSaeson-1.2.4.0-29Ui7SKICkn4HdMa5tx6LD
depends:
    attoparsec-0.13.2.2-edlJ1qiIMBKPe2fnELys4 base-4.10.1.0
    base-compat-0.9.3-915GC5pH10BBmcMnCvMsPA containers-0.5.10.2
    deepseq-1.4.3.0 dlist-0.8.0.4-8Td44GecKNEJmy7QK3HIQc
    ghc-prim-0.5.1.1 hashable-1.2.7.0-D1kf6WO5TlN7xk82E4ZIan
    scientific-0.3.5.2-6cyGrFW0qofJtQe5gZMBGX
    tagged-0.8.5-BP06XmR1GLaIsvsOKwGst2 template-haskell-2.12.0.0
    text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz
    th-abstraction-0.2.6.0-KdJUlqAwMfUIgxZVMgLLVd time-1.8.0.2
    time-locale-compat-0.1.1.3-EeYCrKbfyeWLGJYmfXhrGy
    unordered-containers-0.2.9.0-GWvuj0HLmUnDmBShmJCvae
    uuid-types-1.0.3-7SGDQuL1CwqDmbty1Mwily
    vector-0.12.0.1-JlawpRjIcMJIYPJVsWriIA bytestring-0.10.8.2
abi-depends: attoparsec-0.13.2.2-edlJ1qiIMBKPe2fnELys4=923ea4b48e3ff86a32743bf7d135ea3e
             base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             base-compat-0.9.3-915GC5pH10BBmcMnCvMsPA=b23a246a62afd271167dd1ea1b77583b
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             deepseq-1.4.3.0=e843b5d736cc095915bf2399fddf152e
             dlist-0.8.0.4-8Td44GecKNEJmy7QK3HIQc=891025a77d043cfd28f763ce7f5a4b16
             ghc-prim-0.5.1.1=84323a6edd008b04bf217464a4ccaf16
             hashable-1.2.7.0-D1kf6WO5TlN7xk82E4ZIan=7c14723fffdda860d330f4ccf53597f4
             scientific-0.3.5.2-6cyGrFW0qofJtQe5gZMBGX=7aedff29b89e83530bb1e2cdf3ff8b50
             tagged-0.8.5-BP06XmR1GLaIsvsOKwGst2=b5d07becd47ba21e20b584b61ad0f06d
             template-haskell-2.12.0.0=24d98a36b9e0dbd4d443161d478c05b2
             text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz=29872508833c96394f0471371217bab0
             th-abstraction-0.2.6.0-KdJUlqAwMfUIgxZVMgLLVd=10ae769acb289f778901fba63fa6dabb
             time-1.8.0.2=d7392e85059cb108aeb68d6e24815970
             time-locale-compat-0.1.1.3-EeYCrKbfyeWLGJYmfXhrGy=112a439dbb7402a620113b8ac6cc712d
             unordered-containers-0.2.9.0-GWvuj0HLmUnDmBShmJCvae=b402656649e5f5df6537cabd8124c4af
             uuid-types-1.0.3-7SGDQuL1CwqDmbty1Mwily=57ea9cee1932ecc182feef039579eb9f
             vector-0.12.0.1-JlawpRjIcMJIYPJVsWriIA=137c9db50bf637e10c6e6dd9e685ce59
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
haddock-interfaces: /usr/share/doc/haskell-aeson/html/aeson.haddock
haddock-html: /usr/share/doc/haskell-aeson/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-aeson-1.2.4.0-10-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-aeson.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: aeson
version: 1.2.4.0
id: aeson-1.2.4.0-FhLJrcwJWSLDqhx0AuRAao
key: aeson-1.2.4.0-FhLJrcwJWSLDqhx0AuRAao
license: BSD3
copyright: (c) 2011-2016 Bryan O'\''Sullivan
           (c) 2011 MailRank, Inc.
maintainer: Adam Bergmark <adam@bergmark.nl>
stability: experimental
homepage: https://github.com/bos/aeson
synopsis: Fast JSON parsing and encoding
description:
    A JSON parsing and encoding library optimized for ease of use
    and high performance.
    .
    To get started, see the documentation for the @Data.Aeson@ module
    below.
    .
    Parsing performance on a late 2013 MacBook Pro (2.6GHz Core i7),
    running 64-bit GHC 7.10.1, for mostly-English tweets from Twitter'\''s
    JSON search API:
    .
    * 6.4 KB payloads, English: 7570 msg\/sec (47.6 MB\/sec)
    .
    * 14.6 KB payloads, Japanese: 3261 msg\/sec (46.6 MB\/sec)
    .
    Encoding performance on the same machine and data:
    .
    * 6.4 KB payloads, English: 22738 msg\/sec (142.9 MB\/sec)
    .
    * 14.6 KB payloads, Japanese: 15911 msg\/sec (227.4 MB\/sec)
    .
    (A note on naming: in Greek mythology, Aeson was the father of Jason.)
category: Text, Web, JSON
author: Bryan O'\''Sullivan <bos@serpentine.com>
exposed: True
indefinite: False
exposed-modules:
    Data.Aeson Data.Aeson.Encode Data.Aeson.Encoding
    Data.Aeson.Encoding.Internal Data.Aeson.Internal
    Data.Aeson.Internal.Time Data.Aeson.Parser
    Data.Aeson.Parser.Internal Data.Aeson.TH Data.Aeson.Text
    Data.Aeson.Types
hidden-modules: Data.Aeson.Compat Data.Aeson.Encoding.Builder
                Data.Aeson.Internal.Functions Data.Aeson.Parser.Unescape
                Data.Aeson.Parser.Time Data.Aeson.Types.FromJSON
                Data.Aeson.Types.Generic Data.Aeson.Types.ToJSON
                Data.Aeson.Types.Class Data.Aeson.Types.Internal
                Data.Attoparsec.Time Data.Attoparsec.Time.Internal
                Data.Aeson.Parser.UnescapePure
abi: 83c3b3d90618343923877b4090242cdb
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/aeson-1.2.4.0
library-dirs: /usr/lib/ghc-8.2.2/site-local/aeson-1.2.4.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/aeson-1.2.4.0
hs-libraries: HSaeson-1.2.4.0-FhLJrcwJWSLDqhx0AuRAao
depends:
    attoparsec-0.13.2.2-edlJ1qiIMBKPe2fnELys4 base-4.10.1.0
    base-compat-0.9.3-915GC5pH10BBmcMnCvMsPA containers-0.5.10.2
    deepseq-1.4.3.0 dlist-0.8.0.4-8Td44GecKNEJmy7QK3HIQc
    ghc-prim-0.5.1.1 hashable-1.2.7.0-D1kf6WO5TlN7xk82E4ZIan
    scientific-0.3.5.2-6cyGrFW0qofJtQe5gZMBGX
    tagged-0.8.5-BP06XmR1GLaIsvsOKwGst2 template-haskell-2.12.0.0
    text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz
    th-abstraction-0.2.6.0-KdJUlqAwMfUIgxZVMgLLVd time-1.8.0.2
    time-locale-compat-0.1.1.3-EeYCrKbfyeWLGJYmfXhrGy
    unordered-containers-0.2.9.0-AIQ8bV884oMFcq0To2pA1G
    uuid-types-1.0.3-7SGDQuL1CwqDmbty1Mwily
    vector-0.12.0.1-JlawpRjIcMJIYPJVsWriIA bytestring-0.10.8.2
abi-depends: attoparsec-0.13.2.2-edlJ1qiIMBKPe2fnELys4=923ea4b48e3ff86a32743bf7d135ea3e
             base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             base-compat-0.9.3-915GC5pH10BBmcMnCvMsPA=b23a246a62afd271167dd1ea1b77583b
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             deepseq-1.4.3.0=e843b5d736cc095915bf2399fddf152e
             dlist-0.8.0.4-8Td44GecKNEJmy7QK3HIQc=891025a77d043cfd28f763ce7f5a4b16
             ghc-prim-0.5.1.1=84323a6edd008b04bf217464a4ccaf16
             hashable-1.2.7.0-D1kf6WO5TlN7xk82E4ZIan=7c14723fffdda860d330f4ccf53597f4
             scientific-0.3.5.2-6cyGrFW0qofJtQe5gZMBGX=7aedff29b89e83530bb1e2cdf3ff8b50
             tagged-0.8.5-BP06XmR1GLaIsvsOKwGst2=b5d07becd47ba21e20b584b61ad0f06d
             template-haskell-2.12.0.0=24d98a36b9e0dbd4d443161d478c05b2
             text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz=29872508833c96394f0471371217bab0
             th-abstraction-0.2.6.0-KdJUlqAwMfUIgxZVMgLLVd=10ae769acb289f778901fba63fa6dabb
             time-1.8.0.2=d7392e85059cb108aeb68d6e24815970
             time-locale-compat-0.1.1.3-EeYCrKbfyeWLGJYmfXhrGy=112a439dbb7402a620113b8ac6cc712d
             unordered-containers-0.2.9.0-AIQ8bV884oMFcq0To2pA1G=5c8877e146af6c27c44eb74d4cb22e80
             uuid-types-1.0.3-7SGDQuL1CwqDmbty1Mwily=57ea9cee1932ecc182feef039579eb9f
             vector-0.12.0.1-JlawpRjIcMJIYPJVsWriIA=137c9db50bf637e10c6e6dd9e685ce59
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
haddock-interfaces: /usr/share/doc/haskell-aeson/html/aeson.haddock
haddock-html: /usr/share/doc/haskell-aeson/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
